#
# spec file for package libnl-1_1
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libnl-1_1
%define lname	libnl-1_1-1
Summary:        Convenience library for kernel netlink sockets
License:        LGPL-2.1
Group:          Development/Libraries/Other
Version:        1.1
Release:        136.4
# bug437293
%ifarch ppc64
Obsoletes:      libnl-64bit
%endif
#
Url:            http://people.suug.ch/~tgr/libnl/
Source:         http://people.suug.ch/~tgr/libnl/files/libnl-%version.tar.bz2
Source99:       baselibs.conf
Patch0:         libnl-1.1.diff
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} >= 1140
BuildRequires:  linux-glibc-devel >= 2.6.23
%endif
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
BuildRequires:  linux-kernel-headers >= 2.6.23
%endif
%if 0%{?rhel_version} || 0%{?centos_version} || 0%{?fedora_version}
BuildRequires:  kernel-headers >= 2.6.23
%endif
BuildRequires:  pkgconfig >= 0.21
# Added for 12.1
Obsoletes:      libnl < %version-%release
Provides:       libnl = %version-%release

%description
This package contains a convenience library to simplify using the Linux
kernels netlink sockets interface for network manipulation.

%package -n %lname
Summary:        Convenience library for working with Netlink sockets
License:        LGPL-2.1
Group:          System/Libraries

%description -n %lname
The libnl suite is a collection of libraries providing APIs to
netlink protocol based Linux kernel interfaces.

%package devel
Summary:        Convenience library for kernel netlink sockets
License:        LGPL-2.1+
Group:          Development/Libraries/Other
Requires:       %name = %version-%release
# bug437293
%ifarch ppc64
Obsoletes:      libnl-devel-64bit
%endif
#
Provides:       libnl-devel = %release-%version

%description devel
This package contains a convenience library to simplify using the Linux
kernels netlink sockets interface for network manipulation.

%prep
%setup -q -n libnl-%version
%patch0 -p1

%build
%configure \
    --prefix=%_prefix \
    --libdir=/%_lib \
    --includedir=%_includedir
make %{?_smp_mflags}

%install
make install DESTDIR="%buildroot"
mkdir -p %buildroot/%_libdir/pkgconfig
mv %buildroot/%_lib/pkgconfig/* %buildroot/%_libdir/pkgconfig

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
/%_lib/libnl*.so.*
%doc COPYING ChangeLog

%files devel
%defattr(-,root,root,0755)
%_includedir/netlink/
/%_lib/libnl*.so
%_libdir/pkgconfig/*.pc

%changelog
* Wed Dec 19 2012 jengelh@inai.de
- Have package build successfully with non-SUSE
* Sat Dec 31 2011 jengelh@medozas.de
- License clarification
* Wed Oct  5 2011 uli@suse.com
- cross-build fix: use %%configure macro
* Thu Sep 15 2011 jengelh@medozas.de
- Second attempt at getting baselibs.conf more right
* Wed Sep 14 2011 jengelh@medozas.de
- Remove Conflicts tag, this will be automatically detected
* Mon Sep 12 2011 jengelh@medozas.de
- Fix up baselibs.conf to name the right packages
- Restore BuildRequires for non-SUSE
* Wed Sep  7 2011 jengelh@medozas.de
- Disarm %%-in-a-comment (rpmlint warning)
- Use %%_smp_mflags
- Remove redundant %%clean section
- Run spec-beautifier
* Mon Sep  5 2011 jengelh@medozas.de
- Rename libnl -> libnl-1_1 to allow for concurrent installations
  of (newer versions of) libnl libraries
* Sat Apr 24 2010 coolo@novell.com
- buildrequire pkg-config to fix provides
* Wed Dec 16 2009 jengelh@medozas.de
- Add baselibs.conf as a source
- Add baselib definitions for SPARC
- Enable parallel building
* Fri Jun 12 2009 coolo@novell.com
- fix build with glibc 2.10
* Thu Feb  5 2009 bphilips@suse.de
- baselibs.conf: create -32bit packages. Required to compile Intel
  WiMax tools.
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Tue Nov 11 2008 jpr@novell.com
- Add baselibs.conf (bnc#443023)
* Thu Oct  2 2008 maw@suse.de
- Install libraries in %%_lib, not %%{_libdir} (bnc#428433).
* Fri Feb  1 2008 coolo@suse.de
- update to 1.1:
  o patches went upstream
  o Generic netlink support
  o Route Addition/Deletion
  o Fixed reference counting while objects stay in caches.
  ... tons of other fixes
* Fri Jan 25 2008 adrian@suse.de
- fix changelog entries order
* Wed Oct  3 2007 maw@suse.de
- Apply libnl.route.metric-overflow.patch with -p1.
* Sat Aug 25 2007 olh@suse.de
- remove incomplete copies of kernel headers
  linux/types.h were needed
* Fri Aug 24 2007 olh@suse.de
- include linux/types.h
  do not redefine typedefs
  use stddef.h offsetof
  fix out of bounds access in route metric functions
  fix incorrect char usage in nl_str2af
  remove compiler warnings by checking vasprintf return value
* Wed Aug 22 2007 dmueller@suse.de
- fix accesses of free'd memory which crash NetworkManager-kde
* Wed Aug 22 2007 dmueller@suse.de
- update to 1.0-pre6:
  * fixes write after delete crashes
  * fixes realloc() handling
  * fixes format string warnings
  * fixes invalid free in nl_addr_parse for AF_UNSPEC addresses
  * fixes double nlmsg_free() in nl_recvmsgs() while receiving
    a multipart message and the read was interrupted.
* Sun Feb 19 2006 ro@suse.de
- fix build on ia64, ppc64, s390x
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Nov 15 2005 yxu@suse.de
- fixed conflicting type definition
* Fri Nov  4 2005 rml@suse.de
- Update to 1.0-pre5
* Mon Oct 31 2005 gekker@suse.de
- Initial import into autobuild Version 1.0-pre3
- Patch makefile
